@@ -26,16 +26,16 @@ class HasCorrectItems(ExperimentTest):
                           'catreportj_*.jpg',
                           'pyscript.m']
 
-        res = self.xnat_instance.select.experiment(experiment_id)\
-                .resource('CAT12_SEGMENT')
+        e = self.xnat_instance.select.experiment(experiment_id)
+        res = e.resource('CAT12_SEGMENT')
 
         file_list = set([e.attributes()['Name'] for e in res.files()])
         missing = []
         for e in expected_items:
-            if not [f for f in file_list if fnmatch(f, e)] :
+            if not [f for f in file_list if fnmatch(f, e)]:
                 missing.append(e)
 
-        if missing :
+        if missing:
             return Results(False, data=missing)
 
         return Results(True, data=[])
@@ -43,7 +43,8 @@ class HasCorrectItems(ExperimentTest):
     def report(self):
         report = []
         if self.results.data:
-            report.append(('Missing items: %s.'%self.results.data).replace('\'','`'))
+            item = ('Missing items: %s.' % self.results.data).replace('\'', '`')
+            report.append(item)
         return report
 
 
@@ -59,22 +60,23 @@ class HasCorrectCATVersion(ExperimentTest):
         expected_cat_version = 'CAT version: CAT12.6 Release: 1450'
 
         data = self.xnat_instance.array.mrsessions(experiment_id=experiment_id,
-            columns=['label']).data
-        exp_label, project, subject_id = [data[0][e] for e in \
-            ['label', 'project', 'xnat:mrsessiondata/subject_id']]
+                                                   columns=['label']).data
+        columns = ['label', 'project', 'xnat:mrsessiondata/subject_id']
+        exp_label, project, subject_id = [data[0][e] for e in columns]
 
         res = self.xnat_instance.select.project(project).subject(subject_id)\
             .experiment(experiment_id).resource('CAT12_SEGMENT')
-        log = res.file('LOGS/%s.log'%exp_label)
+        log = res.file('LOGS/%s.log' % exp_label)
 
         if not log.exists():
             return Results(False, data=['CAT12Segment log file not found.'])
 
         log_data = self.xnat_instance.get(log.attributes()['URI']).text
-        cat_version = [line for line in log_data.splitlines() if line.startswith('CAT version:')]
+        cat_version = [line for line in log_data.splitlines()
+                       if line.startswith('CAT version:')]
 
-        if not cat_version or cat_version[0] != expected_cat_version :
-            return Results(False, data=['Incorrect CAT version: %s' %cat_version])
+        if not cat_version or cat_version[0] != expected_cat_version:
+            return Results(False, data=['Incorrect CAT version: %s' % cat_version])
 
         return Results(True, data=[])
 
@@ -92,13 +94,13 @@ class HasCorrectSPMVersion(ExperimentTest):
         expected_spm_version = 'SPM version: SPM12 Release: 7487'
 
         data = self.xnat_instance.array.mrsessions(experiment_id=experiment_id,
-            columns=['label']).data
-        exp_label, project, subject_id = [data[0][e] for e in \
-            ['label', 'project', 'xnat:mrsessiondata/subject_id']]
+                                                   columns=['label']).data
+        elements = ['label', 'project', 'xnat:mrsessiondata/subject_id']
+        exp_label, project, subject_id = [data[0][e] for e in elements]
 
         res = self.xnat_instance.select.project(project).subject(subject_id)\
             .experiment(experiment_id).resource('CAT12_SEGMENT')
-        log = res.file('LOGS/%s.log'%exp_label)
+        log = res.file('LOGS/%s.log' % exp_label)
 
         if not log.exists():
             return Results(False, data=['CAT12Segment log file not found.'])
@@ -106,8 +108,8 @@ class HasCorrectSPMVersion(ExperimentTest):
         log_data = self.xnat_instance.get(log.attributes()['URI']).text
         spm_version = [line for line in log_data.splitlines() if line.startswith('SPM version:')]
 
-        if not spm_version or spm_version[0] != expected_spm_version :
-            return Results(False, data=['Incorrect SPM version: %s' %spm_version])
+        if not spm_version or spm_version[0] != expected_spm_version:
+            return Results(False, data=['Incorrect SPM version: %s' % spm_version])
 
         return Results(True, data=[])
 
@@ -126,24 +128,24 @@ class HasCorrectMatlabVersion(ExperimentTest):
         expected_matlab_version = 'MATLAB Version: 9.5.0* (R2018b)*'
 
         data = self.xnat_instance.array.mrsessions(experiment_id=experiment_id,
-            columns=['label']).data
-        exp_label, project, subject_id = [data[0][e] for e in \
-            ['label', 'project', 'xnat:mrsessiondata/subject_id']]
+                                                   columns=['label']).data
+        elements = ['label', 'project', 'xnat:mrsessiondata/subject_id']
+        exp_label, project, subject_id = [data[0][e] for e in elements]
 
         res = self.xnat_instance.select.project(project).subject(subject_id)\
             .experiment(experiment_id).resource('CAT12_SEGMENT')
-        log = res.file('LOGS/%s.log'%exp_label)
+        log = res.file('LOGS/%s.log' % exp_label)
 
         if not log.exists():
             return Results(False, data=['CAT12Segment log file not found.'])
 
         log_data = self.xnat_instance.get(log.attributes()['URI']).text
 
-        matlab_version = [line for line in log_data.splitlines() \
-            if line.startswith('MATLAB Version')]
-        if not matlab_version or not fnmatch(matlab_version[0],expected_matlab_version) :
-            return Results(False, data=['Incorrect Matlab version: %s' \
-                %matlab_version])
+        matlab_version = [line for line in log_data.splitlines()
+                          if line.startswith('MATLAB Version')]
+        if not matlab_version or not fnmatch(matlab_version[0], expected_matlab_version):
+            return Results(False, data=['Incorrect Matlab version: %s'
+                                        % matlab_version])
 
         return Results(True, data=[])
 
@@ -162,25 +164,25 @@ class HasCorrectOSVersion(ExperimentTest):
         expected_kernel_version = 'Operating System: Linux 4.4.120*'
 
         data = self.xnat_instance.array.mrsessions(experiment_id=experiment_id,
-            columns=['label']).data
-        exp_label, project, subject_id = [data[0][e] for e in \
-            ['label', 'project', 'xnat:mrsessiondata/subject_id']]
+                                                   columns=['label']).data
+        elements = ['label', 'project', 'xnat:mrsessiondata/subject_id']
+        exp_label, project, subject_id = [data[0][e] for e in elements]
 
         res = self.xnat_instance.select.project(project).subject(subject_id)\
             .experiment(experiment_id).resource('CAT12_SEGMENT')
-        log = res.file('LOGS/%s.log'%exp_label)
+        log = res.file('LOGS/%s.log' % exp_label)
 
         if not log.exists():
             return Results(False, data=['CAT12Segment log file not found.'])
 
         log_data = self.xnat_instance.get(log.attributes()['URI']).text
-        kernel_version = [line for line in log_data.splitlines() \
-            if line.startswith('Operating System:')]
+        kernel_version = [line for line in log_data.splitlines()
+                          if line.startswith('Operating System:')]
 
         if not kernel_version or \
-                not fnmatch(kernel_version[0],expected_kernel_version):
-            return Results(False, data=['Incorrect OS version: %s' \
-                % kernel_version])
+                not fnmatch(kernel_version[0], expected_kernel_version):
+            return Results(False, data=['Incorrect OS version: %s'
+                                        % kernel_version])
 
         return Results(True, data=[])
 
@@ -194,14 +196,12 @@ class CAT12SegmentIQRScore(ExperimentTest):
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E01613',
 
-    def run(self,experiment_id):
+    def run(self, experiment_id):
 
         data = self.xnat_instance.array.mrsessions(experiment_id=experiment_id,
                                                    columns=['label']).data
-        exp_label, project, subject_id = [data[0][e] for e in \
-                                          ['label',
-                                           'project',
-                                           'xnat:mrsessiondata/subject_id']]
+        elements = ['label', 'project', 'xnat:mrsessiondata/subject_id']
+        exp_label, project, subject_id = [data[0][e] for e in elements]
 
         res = self.xnat_instance.select.project(project).subject(subject_id) \
             .experiment(experiment_id).resource('CAT12_SEGMENT')
@@ -210,7 +210,7 @@ class CAT12SegmentIQRScore(ExperimentTest):
             return Results(False, data=['CAT12Segment log file not found.'])
         log_data = self.xnat_instance.get(log.attributes()['URI']).text
 
-        iqr = [line for line in log_data.splitlines() \
+        iqr = [line for line in log_data.splitlines()
                if line.startswith('Image Quality Rating (IQR)')]
 
         score_str = iqr[0].split(':')[1].strip()
@@ -226,16 +226,15 @@ class CAT12SegmentExecutionTime(ExperimentTest):
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E01613',
 
-    def run(self,experiment_id):
+    def run(self, experiment_id):
         import dateparser
         import datetime
         from fnmatch import fnmatch
 
         data = self.xnat_instance.array.mrsessions(experiment_id=experiment_id,
                                                    columns=['label']).data
-        exp_label, project, subject_id = [data[0][e] for e in \
-                                          ['label',
-                                           'project',
+        exp_label, project, subject_id = [data[0][e] for e in
+                                          ['label', 'project',
                                            'xnat:mrsessiondata/subject_id']]
 
         res = self.xnat_instance.select.project(project).subject(subject_id) \
@@ -248,9 +247,9 @@ class CAT12SegmentExecutionTime(ExperimentTest):
         tags = ['* - Running \'CAT12: Segmentation\'',
                 '* - Done    \'CAT12: Segmentation\'']
         dates = []
-        for tag in tags :
+        for tag in tags:
             for line in log_data.splitlines():
-                if fnmatch(line,tag) :
+                if fnmatch(line, tag):
                     dt = line.split(' - ')[0]
                     dates.append(dateparser.parse(dt))
                     break
@@ -260,7 +259,7 @@ class CAT12SegmentExecutionTime(ExperimentTest):
 
         result = False
         tdelta = max(dates) - min(dates)
-        if datetime.timedelta(minutes=20) < tdelta < datetime.timedelta(minutes=60) :
+        if datetime.timedelta(minutes=20) < tdelta < datetime.timedelta(minutes=60):
             result = True
 
         return Results(result, data=['%s' % tdelta])
@@ -276,7 +275,8 @@ class CAT12SegmentSnapshot(ExperimentTest):
 
     def run(self, experiment_id):
         import os.path as op
-        import tempfile, os
+        import os
+        import tempfile
         from ..sanity import data
 
         # if os.getenv('SKIP_SNAPSHOTS_TESTS') == 'True':
@@ -284,10 +284,10 @@ class CAT12SegmentSnapshot(ExperimentTest):
         #         data=['Skipping it. (SKIP_SNAPSHOTS_TESTS)'])
 
         p = data.HasPreferredT1(self.lut, self.xnat_instance)
-        e = p.preferred_t1(experiment_id)
+        scan_id = p.preferred_t1(experiment_id)
 
-        resources_files = list(self.xnat_instance.select.experiment(experiment_id) \
-                               .scan(e).resource('NIFTI').files())
+        e = self.xnat_instance.select.experiment(experiment_id)
+        resources_files = list(e.scan(scan_id).resource('NIFTI').files())
 
         if len(resources_files) == 0:
             return Results(False, data=['T1 not found.'])
@@ -296,13 +296,11 @@ class CAT12SegmentSnapshot(ExperimentTest):
             if f.label().endswith('.nii.gz'):
                 break
 
-        fd, path = tempfile.mkstemp(suffix='.nii.gz')
-        f.get(dest=path)
-        t1_fp = path
+        fd, t1_fp = tempfile.mkstemp(suffix='.nii.gz')
         os.close(fd)
+        f.get(dest=t1_fp)
 
-        resources_files = list(self.xnat_instance.select.experiment(experiment_id) \
-                               .resource('CAT12_SEGMENT').files())
+        resources_files = list(e.resource('CAT12_SEGMENT').files())
 
         if len(resources_files) == 0:
             return Results(False, data=['CAT12 results not found.'])
@@ -315,13 +313,14 @@ class CAT12SegmentSnapshot(ExperimentTest):
             return Results(False, data=['p1 map (CAT) not found.'])
 
         fd, c1_fp = tempfile.mkstemp(suffix='.nii.gz')
-        f.get(dest = c1_fp)
         os.close(fd)
+        f.get(dest=c1_fp)
 
         from . import probamap_snapshot
         paths = probamap_snapshot(t1_fp, c1_fp)
 
-
+        os.remove(t1_fp)
+        os.remove(c1_fp)
         return Results(True, data=paths)
 
     def report(self):
@@ -331,4 +330,5 @@ class CAT12SegmentSnapshot(ExperimentTest):
             report.append('![snapshot](%s)' % path)
         return report
 
-#class HasNormalCAT12Volumes(ExperimentTest):
+
+# class HasNormalCAT12Volumes(ExperimentTest):
