@@ -15,21 +15,21 @@ class HasCorrectItems(ExperimentTest):
     passing = 'BBRCDEV_E00365',
     failing = 'BBRCDEV_E00251',
     resource_name = 'FREESURFER6'
+    hippo_items = ['lh.hippoSfLabels-{}.v10.mgz',
+                   'rh.hippoSfLabels-{}.v10.mgz',
+                   'lh.hippoSfLabels-{}.v10.FSvoxelSpace.mgz',
+                   'rh.hippoSfLabels-{}.v10.FSvoxelSpace.mgz',
+                   'lh.hippoSfVolumes-{}.v10.txt',
+                   'rh.hippoSfVolumes-{}.v10.txt']
+    monomodal_items = ['hippocampal-subfields-T1.log']
+    multimodal_items = ['{}.FSspace.mgz',
+                        'T1_to_{}.v10.lta',
+                        'T1_to_{}.v10.QC.gif',
+                        'T1_to_{}.v10.info']
 
     def run(self, experiment_id):
         import os.path as op
         import bbrc
-        hippo_items = ['lh.hippoSfLabels-%s.v10.mgz',
-                       'rh.hippoSfLabels-%s.v10.mgz',
-                       'lh.hippoSfLabels-%s.v10.FSvoxelSpace.mgz',
-                       'rh.hippoSfLabels-%s.v10.FSvoxelSpace.mgz',
-                       'lh.hippoSfVolumes-%s.v10.txt',
-                       'rh.hippoSfVolumes-%s.v10.txt']
-
-        multimodal_items = ['%s.FSspace.mgz',
-                            'T1_to_%s.v10.lta',
-                            'T1_to_%s.v10.QC.gif',
-                            'T1_to_%s.v10.info']
 
         fn = '%s_items.json' % self.resource_name.lower()
 
@@ -56,16 +56,17 @@ class HasCorrectItems(ExperimentTest):
         ignored = 0
         for each in ['T1', 'T1-T1T2', 'T1-T1IR']:
             is_found = True
-            hi = set([i % each for i in hippo_items])
-            if each in ['T1-T1T2', 'T1-T1IR']:
-                hi = hi.union([e % each[-4:] for e in multimodal_items])
-
+            hi = set([i.format(each) for i in self.hippo_items])
+            if each == 'T1':
+                hi = hi.union(self.monomodal_items)
+            elif each in ['T1-T1T2', 'T1-T1IR']:
+                hi = hi.union([e.format(each[-4:]) for e in self.multimodal_items])
             is_found = len(hi.difference(filenames)) == 0
             if is_found:
                 found_hippo.append(each)
 
             # removing any hippocampus-related files
-            items = [i % each for i in hippo_items]
+            items = [i.format(each) for i in self.hippo_items]
             ignored = ignored + len(unknown.intersection(items))
             unknown = unknown.difference(hi)
 
@@ -87,13 +88,13 @@ class HasCorrectItems(ExperimentTest):
 
 class HasCorrectFreeSurferVersion(ExperimentTest):
     """This test checks the version of FreeSurfer used. Passes if FREESURFER6
-    outputs were created using the expected version (i.e. `v6.0.0-2beb96c`)."""
+    outputs were created using the expected version"""
 
     passing = 'BBRCDEV_E00365',
     failing = 'BBRCDEV_E00251',
     resource_name = 'FREESURFER6'
     freesurfer_version = 'freesurfer-Linux-centos6_x86_64-stable-pub-v6.0.0-2beb96c'
-    __doc__ = __doc__ + ' (expected version: %s)' % freesurfer_version
+    __doc__ = __doc__ + ' (expected version: %s).' % freesurfer_version
 
     def run(self, experiment_id):
         filename = 'build-stamp.txt'
@@ -116,14 +117,13 @@ class HasCorrectFreeSurferVersion(ExperimentTest):
 
 class HasCorrectOSVersion(ExperimentTest):
     """This test checks the OS kernel version on which FreeSurfer was executed.
-    Passes if OS kernel version matches the expected version (i.e. `4.4.120-92.70`);
-    fails otherwise."""
+    Passes if OS kernel version matches the expected version"""
 
     passing = 'BBRCDEV_E00013',
     failing = 'BBRCDEV_E00365',
     resource_name = 'FREESURFER6'
     kernel_version = '4.4.120-92.70-default'
-    __doc__ = __doc__ + ' (expected version: %s)' % kernel_version
+    __doc__ = __doc__ + ' (expected version: %s).' % kernel_version
 
     def run(self, experiment_id):
 
@@ -154,23 +154,23 @@ class IsT1OnlyHippocampalSegmentation(ExperimentTest):
     passing = 'BBRCDEV_E00365',
     failing = 'BBRCDEV_E00015',
     resource_name = 'FREESURFER6'
+    items = ['lh.hippoSfLabels-T1.v10.mgz',
+             'rh.hippoSfLabels-T1.v10.mgz',
+             'lh.hippoSfLabels-T1.v10.FSvoxelSpace.mgz',
+             'rh.hippoSfLabels-T1.v10.FSvoxelSpace.mgz',
+             'lh.hippoSfVolumes-T1.v10.txt',
+             'rh.hippoSfVolumes-T1.v10.txt']
 
     def run(self, experiment_id):
 
         result = False
-        items = ['lh.hippoSfLabels-T1.v10.mgz',
-                 'rh.hippoSfLabels-T1.v10.mgz',
-                 'lh.hippoSfLabels-T1.v10.FSvoxelSpace.mgz',
-                 'rh.hippoSfLabels-T1.v10.FSvoxelSpace.mgz',
-                 'lh.hippoSfVolumes-T1.v10.txt',
-                 'rh.hippoSfVolumes-T1.v10.txt']
 
         x = self.xnat_instance
         r = x.select.experiment(experiment_id).resource(self.resource_name)
         data = x._get_json(r._uri + '/files')
 
         full_items = set([e['Name'] for e in data])
-        common_items = full_items.intersection(items)
+        common_items = full_items.intersection(self.items)
 
         uri = [e['URI'] for e in data
                if 'hippocampal-subfields-T1.log' == str(e['Name'])]
@@ -182,12 +182,15 @@ class IsT1OnlyHippocampalSegmentation(ExperimentTest):
 
         logfile = x.get(uri[0]).text
 
-        result = '(T1 only)' in logfile.splitlines()[1] and \
-                 len(common_items) == len(items)
+        is_t1only = [l for l in logfile.splitlines()
+                     if l.startswith('#@# Hippocampal Subfields processing (T1)')
+                     or l.startswith('#@# Hippocampal Subfields processing (T1 only)')]
+        if is_t1only and len(common_items) == len(self.items):
+            result = True
 
         msg = []
         if not result:
-            missing_items = [e for e in items if e not in full_items]
+            missing_items = [e for e in self.items if e not in full_items]
             if missing_items:
                 m = 'T1-only hippocampal segmentation results missing files: %s'\
                     % ', '.join(missing_items)
@@ -205,88 +208,67 @@ class IsT1T2HippocampalSegmentation(ExperimentTest):
     passing = 'BBRCDEV_E00015',
     failing = 'BBRCDEV_E00365',
     resource_name = 'FREESURFER6'
+    items = ['T1T2.FSspace.mgz',
+             'lh.hippoSfLabels-T1-T1T2.v10.mgz',
+             'rh.hippoSfLabels-T1-T1T2.v10.mgz',
+             'lh.hippoSfLabels-T1-T1T2.v10.FSvoxelSpace.mgz',
+             'rh.hippoSfLabels-T1-T1T2.v10.FSvoxelSpace.mgz',
+             'lh.hippoSfVolumes-T1-T1T2.v10.txt',
+             'rh.hippoSfVolumes-T1-T1T2.v10.txt']
 
     def run(self, experiment_id):
 
         result = False
-        items = ['T1T2.FSspace.mgz',
-                 'lh.hippoSfLabels-T1-T1T2.v10.mgz',
-                 'rh.hippoSfLabels-T1-T1T2.v10.mgz',
-                 'lh.hippoSfLabels-T1-T1T2.v10.FSvoxelSpace.mgz',
-                 'rh.hippoSfLabels-T1-T1T2.v10.FSvoxelSpace.mgz',
-                 'lh.hippoSfVolumes-T1-T1T2.v10.txt',
-                 'rh.hippoSfVolumes-T1-T1T2.v10.txt']
 
         x = self.xnat_instance
         r = x.select.experiment(experiment_id).resource(self.resource_name)
         data = x._get_json(r._uri + '/files')
 
         full_items = set([e['Name'] for e in data])
-        common_items = full_items.intersection(items)
+        common_items = full_items.intersection(self.items)
 
-        result = len(common_items) == len(items)
+        result = len(common_items) == len(self.items)
 
         msg = []
         if not result:
-            missing_items = [e for e in items if e not in full_items]
+            missing_items = [e for e in self.items if e not in full_items]
             if missing_items:
-                m = 'T1+T2 hippocampal segmentation results missing files: %s'\
+                m = 'Missing files: %s'\
                     % ', '.join(missing_items)
                 msg.append(m)
 
         return Results(result, data=msg)
 
 
-class IsT1IRHippocampalSegmentation(ExperimentTest):
+class IsT1IRHippocampalSegmentation(IsT1T2HippocampalSegmentation):
     """This test asserts that FREESURFER6 resource contains T1w+IR multispectral
     (mode B) hippocampal segmentation outputs. Passes if expected T1w+IR output
     files generated by FreeSurfer hippocampal segmentation procedure are found;
     fails otherwise."""
+    __doc__ = IsT1T2HippocampalSegmentation.__doc__.replace('T2w','IR')
 
     passing = 'BBRCDEV_E00399',
     failing = 'BBRCDEV_E00365',
     resource_name = 'FREESURFER6'
-
-    def run(self, experiment_id):
-
-        result = False
-        items = ['T1IR.FSspace.mgz',
-                 'lh.hippoSfLabels-T1-T1IR.v10.mgz',
-                 'rh.hippoSfLabels-T1-T1IR.v10.mgz',
-                 'lh.hippoSfLabels-T1-T1IR.v10.FSvoxelSpace.mgz',
-                 'rh.hippoSfLabels-T1-T1IR.v10.FSvoxelSpace.mgz',
-                 'lh.hippoSfVolumes-T1-T1IR.v10.txt',
-                 'rh.hippoSfVolumes-T1-T1IR.v10.txt']
-
-        x = self.xnat_instance
-        r = x.select.experiment(experiment_id).resource(self.resource_name)
-        data = x._get_json(r._uri + '/files')
-
-        full_items = set([e['Name'] for e in data])
-        common_items = full_items.intersection(items)
-
-        result = len(common_items) == len(items)
-
-        msg = []
-        if not result:
-            missing_items = [e for e in items if e not in full_items]
-            if missing_items:
-                m = 'T1+IR hippocampal segmentation results missing files: %s'\
-                    % ', '.join(missing_items)
-                msg.append(m)
-
-        return Results(result, data=msg)
+    items = ['T1IR.FSspace.mgz',
+             'lh.hippoSfLabels-T1-T1IR.v10.mgz',
+             'rh.hippoSfLabels-T1-T1IR.v10.mgz',
+             'lh.hippoSfLabels-T1-T1IR.v10.FSvoxelSpace.mgz',
+             'rh.hippoSfLabels-T1-T1IR.v10.FSvoxelSpace.mgz',
+             'lh.hippoSfVolumes-T1-T1IR.v10.txt',
+             'rh.hippoSfVolumes-T1-T1IR.v10.txt']
 
 
 class IsT2MultispectralHippoSegRunnable(ExperimentTest):
     """This test checks that the given MRSession can run FreeSurfer's hippocampal
-    segmentation in multispectral mode (mode B) by using an additional T2W scan.
+    segmentation in multispectral mode (mode B) by using an additional T2w scan.
     Fails if no T2w scans are available for running the hippocampal segmentation
     in multispectral mode; passes otherwise."""
 
     passing = 'BBRCDEV_E00399',
     failing = 'BBRCDEV_E00365',
     resource_name = 'FREESURFER6'
+    test_name = 'HasUsableT2'
 
     def run(self, experiment_id):
         x = HasCorrectItems(self.lut, self.xnat_instance)
@@ -297,7 +279,8 @@ class IsT2MultispectralHippoSegRunnable(ExperimentTest):
             msg = 'Invalid FreeSurfer baseline results. Not runnable.'
             return Results(False, data=[msg])
 
-        res = data.HasUsableT2(self.lut, self.xnat_instance).run(experiment_id)
+        test = eval('data.{}'.format(self.test_name))
+        res = test(self.lut, self.xnat_instance).run(experiment_id)
         if not res.has_passed:
             msg = '{} Not runnable.'.format(res.data[0])
             return Results(False, data=[msg])
@@ -305,31 +288,13 @@ class IsT2MultispectralHippoSegRunnable(ExperimentTest):
         return Results(True, data=[])
 
 
-class IsIRMultispectralHippoSegRunnable(ExperimentTest):
-    """This test checks that the given MRSession can run FreeSurfer's hippocampal
-    segmentation in multispectral mode (mode B) by using an additional IR scan.
-    Fails if no IR scans are available for running the hippocampal segmentation
-    in multispectral mode; passes otherwise."""
+class IsIRMultispectralHippoSegRunnable(IsT2MultispectralHippoSegRunnable):
+    __doc__ = IsT2MultispectralHippoSegRunnable.__doc__.replace('T2w', 'IR')
 
     passing = 'BBRCDEV_E00399',
     failing = 'BBRCDEV_E00365',
     resource_name = 'FREESURFER6'
-
-    def run(self, experiment_id):
-        x = HasCorrectItems(self.lut, self.xnat_instance)
-        x.resource_name = self.resource_name
-        res = x.run(experiment_id)
-
-        if not res.has_passed:
-            msg = 'Invalid FreeSurfer baseline results. Not runnable.'
-            return Results(False, data=[msg])
-
-        res = data.HasUsableIR(self.lut, self.xnat_instance).run(experiment_id)
-        if not res.has_passed:
-            msg = '{} Not runnable.'.format(res.data[0])
-            return Results(False, data=[msg])
-
-        return Results(True, data=[])
+    test_name = 'HasUsableIR'
 
 
 class IsFreeSurferTimewiseConsistent(ExperimentTest):
@@ -516,7 +481,6 @@ class AreCAVolumesConsistent(ExperimentTest):
             msg = 'No %s resource found.' % self.resource_name
             return Results(False, data=[msg])
 
-        has_one_hippo = False  # not used but might be useful
         for mode in ['T1', 'T1-T1T2', 'T1-T1IR']:
             ca_vols = r.hippoSfVolumes(mode=mode)
             ca_vols['value'] = pd.to_numeric(ca_vols['value'])
@@ -528,10 +492,15 @@ class AreCAVolumesConsistent(ExperimentTest):
                 if len(ca.items()) == 0:
                     continue
 
-                has_one_hippo = True  # not used but might be useful
-                sorted_ca_vols = [s[0] for s in sorted(ca['value'].items(),
-                                                       key=operator.itemgetter(1))
-                                  if s[0] in regions]
+                # filter out non-CA regions dataframe and
+                # merge FS7 CA partial volumes (head + body)
+                ca2 = dict.fromkeys(regions, 0)
+                for k, v in ca['value'].items():
+                    if k[:3] in regions:
+                        ca2[k[:3]] += v
+
+                sorted_ca_vols = [s[0] for s in sorted(ca2.items(),
+                                                       key=operator.itemgetter(1))]
                 if sorted_ca_vols != regions:
                     msg = '%s-%s: %s' % (mode, s,
                                          ' < '.join(sorted_ca_vols))
