@@ -97,8 +97,8 @@ class SPM12SegmentMultichannelHoles(ExperimentTest):
     the size of such _holes_ when present, failing if its size > 20000 and
     passing otherwise. In addition, test generates a modified version of the
     original c2 map with those misclassified c5 areas labeled as c2.
-    A snapshot is included to inspect this modified map visually (original SPM
-    c2 map in green and detected _holes_ in red)."""
+    A snapshot composition is included to inspect this modified map visually
+    (original c2 segmentation in green and detected _holes_ in red)."""
 
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E01613',
@@ -144,6 +144,8 @@ class SPM12SegmentMultichannelHoles(ExperimentTest):
         from . import holes_snapshot
         snapshots = holes_snapshot(filepaths[0], diff_img)
         os.remove(diff_img)
+        for fp in filepaths:
+            os.remove(fp)
 
         res = size < 20000  # Fixme : with some threshold value
         return Results(res, data={'size': '{}'.format(size),
