@@ -574,10 +574,10 @@ class HasCorrectSequences(ExperimentTest):
 
     def run(self, experiment_id):
 
-        def resolve_aliases(l, aliases, logs=[]):
+        def resolve_aliases(seq_list, aliases, logs=[]):
             new_list = []
             transtab = {}
-            for e in l:
+            for e in seq_list:
                 has_alias = False
                 for k, v in aliases.items():
                     if e in v:
@@ -590,6 +590,21 @@ class HasCorrectSequences(ExperimentTest):
                     transtab[e] = e
             return new_list, transtab
 
+        def resolve_mutexes(seq_list, obligatory_items, mutexes, logs=[]):
+
+            for s in seq_list:
+                for mutex_item1, mutex_item2 in mutexes.items():
+                    if s == mutex_item1:
+                        obligatory_items.pop(mutex_item2)
+                        logs.append('{} is mutually exclusive with '
+                                    '{}<br>'.format(mutex_item2, s))
+                    elif s == mutex_item2:
+                        obligatory_items.pop(mutex_item1)
+                        logs.append('{} is mutually exclusive with '
+                                    '{}<br>'.format(mutex_item1, s))
+
+            return obligatory_items
+
         import json
         import bbrc
         import pandas as pd
@@ -599,11 +614,9 @@ class HasCorrectSequences(ExperimentTest):
         fp = op.join(op.dirname(bbrc.__file__), 'data', 'validation_rules.json')
         with open(fp, 'r') as f:
             rules = json.load(f)
-        cols = ['ID', 'label', 'project', 'subject_ID']
-        labels = self.xnat_instance.array.experiments(experiment_id=experiment_id,
-                                                      columns=cols).data[0]
-        project_id = labels['project']
 
+        e = self.xnat_instance.select.experiment(experiment_id)
+        project_id = e.attrs.get('project')
         # Ad-hoc exception added for DEVELOPMENT ENVIRONMENT test cases validation
         if project_id == 'testenv' and 'devxnat' in self.xnat_instance._server:
             columns = ['ID', 'xnat:imagesessiondata/session_type']
@@ -614,6 +627,7 @@ class HasCorrectSequences(ExperimentTest):
             project_id = project_id.replace('+', '_PLUS')
 
         log.info('*** %s' % project_id)
+
         # Sequences part
         seqdata = []
         cols = ['xnat:imageScanData/type', 'xnat:imageScanData/frames']
@@ -629,7 +643,7 @@ class HasCorrectSequences(ExperimentTest):
             for k in keys:
                 row.append(scan[k].rstrip(' '))  # Remove strange trailing spaces
 
-            scan = self.xnat_instance.select.experiment(experiment_id).scan(scan_id)
+            scan = e.scan(scan_id)
             uri = scan._uri + '/resources'
             sc = {e['xnat_abstractresource_id']: e
                   for e in self.xnat_instance._get_json(uri)}
@@ -667,6 +681,7 @@ class HasCorrectSequences(ExperimentTest):
         # If the project does not have predefined rules, set default (empty) rules
         pr = rules.get(project_id, {'obligatory': {},
                                     'aliases': {},
+                                    'mutually_exclusive': {},
                                     'warning_if_missing': {},
                                     'silently_identified': {}})
         if project_id not in rules:
@@ -675,19 +690,23 @@ class HasCorrectSequences(ExperimentTest):
             return Results(None, data=[msg])
 
         # Resolving aliases, transtab is a translation table
-        session_seqlist, transtab = resolve_aliases(session_seqlist,
-                                                    pr['aliases'],
-                                                    logs)
+        session_seqlist, trans_table = resolve_aliases(session_seqlist,
+                                                       pr['aliases'],
+                                                       logs)
+
+        # Resolving mutually exclusive sequence items
+        pr['obligatory'] = resolve_mutexes(session_seqlist, pr['obligatory'],
+                                           pr['mutually_exclusive'], logs)
         # Checking obligatory sequences
         for k, v in pr['obligatory'].items():
             if session_seqlist.count(k) < 1:
                 continue
 
             key = 'file_count'
-            if k in transtab and 'CHESS' not in transtab[k]:
+            if k in trans_table and 'CHESS' not in trans_table[k]:
                 key = 'frames'
 
-            n_frames = df2[df2['type'] == transtab[k]][key].to_list()
+            n_frames = df2[df2['type'] == trans_table[k]][key].to_list()
             if session_seqlist.count(k) == 1:
                 if n_frames[0] != str(v):
                     msg = '*** %s is unique but has wrong file_count '\
@@ -695,7 +714,7 @@ class HasCorrectSequences(ExperimentTest):
                     logs.append(msg)
                     result = 2
             if session_seqlist.count(k) > 1:
-                occ = df2[df2['type'] == transtab[k]]['ID'].tolist()
+                occ = df2[df2['type'] == trans_table[k]]['ID'].tolist()
                 for i, s in enumerate(occ):
                     if n_frames[i] != str(v):
                         msg = '*** %s (scanID: %s) has wrong file_count (%s ' \
