@@ -109,14 +109,12 @@ class IsScannerVersionCorrect(ExperimentTest):
 
     passing = 'BBRCDEV_E00745',
     failing = 'BBRCDEV_E00281',
+    scanner_info = {'Manufacturer': ['SIEMENS'],
+                    'ManufacturersModelName': ['Biograph64', 'Biograph64_mCT'],
+                    'SoftwareVersion(s)': ['VG51C']}
 
     def run(self, experiment_id):
 
-        pet_scanner_info = {'Manufacturer': ['SIEMENS'],
-                            'ManufacturersModelName': ['Biograph64',
-                                                       'Biograph64_mCT'],
-                            'SoftwareVersion(s)': ['VG51C']}
-
         data = self.xnat_instance.array.experiments(
             experiment_id=experiment_id,
             experiment_type='xnat:imageSessionData',
@@ -138,13 +136,13 @@ class IsScannerVersionCorrect(ExperimentTest):
             str(item['desc']).replace(" ", "").replace("&rsquo;s", "s"):
             str(item['value']) for item in dcm_dump}
 
-        missing_tags = list(set(pet_scanner_info.keys()).
+        missing_tags = list(set(self.scanner_info.keys()).
                             difference(set(dcm_attribs.keys())))
         if missing_tags:
             return Results(False, ['%s DICOM tags not present' % missing_tags])
 
-        wrong_items = {k: dcm_attribs[k] for k in pet_scanner_info
-                       if dcm_attribs[k] not in pet_scanner_info[k]}
+        wrong_items = {k: dcm_attribs[k] for k in self.scanner_info
+                       if dcm_attribs[k] not in self.scanner_info[k]}
 
         result = len(wrong_items) == 0
         data = []
@@ -249,12 +247,14 @@ class HasUsableT1(ExperimentTest):
     uses absolute time distance (`timedelta`) between PET and MR acquisitions to
     select the closest MR session available. This test passes if there is an MR
     Session with a usable T1 sequence (`T1_ALFA1`) from the given subject that
-    its acquisition date is closer than 1 year time to the PET acquisition data.
+    its acquisition date is closer than 500 days time to the PET acquisition data.
     Fails otherwise. *Requisites:* This test depends on `HasPreferredT1` and
     `IsFreeSurferRunnable` test results of *ArchivingValidator*."""
 
     passing = 'BBRCDEV_E00745',
     failing = 'BBRCDEV_E02102',
+    included_projects = ['ALFA_PLUS', 'ALFA_OPCIONAL',
+                         'ALFA_PLUS2', 'EPAD', 'testenv']
 
     def get_validation_data(self, experiment_id, experiment_name,
                             validator='ArchivingValidator'):
@@ -284,10 +284,7 @@ class HasUsableT1(ExperimentTest):
         if not mris:
             return Results(False, ['No MR sessions found.'])
 
-        # discard MRIs where project is not from the list
-        included_projects = ['ALFA_PLUS', 'ALFA_OPCIONAL',
-                             'ALFA_PLUS2', 'EPAD', 'testenv']
-        valid_mris = [i for i in mris if i['project'] in included_projects]
+        valid_mris = [i for i in mris if i['project'] in self.included_projects]
 
         candidate_t1s = []
         for mri in valid_mris:
@@ -317,10 +314,10 @@ class HasUsableT1(ExperimentTest):
         valid_t1 = sorted(candidate_t1s,
                           key=lambda item: item['acq_timedelta'],
                           reverse=False)[0]
-        # Restriction: MR and PET aquisitions should be closer than 1 year time
-        if valid_t1['acq_timedelta'] > dt.timedelta(days=365):
-            return Results(False, ['MR sessions with valid T1 scans exceed 1 '
-                                   'year time-distance required between MR '
+        # Restriction: MR and PET aquisitions should be closer than 500 days time
+        if valid_t1['acq_timedelta'] > dt.timedelta(days=500):
+            return Results(False, ['MR sessions with valid T1 scans exceed 500 '
+                                   'days time-distance required between MR '
                                    'and PET acquisitions.'])
 
         # timedelta objects are not JSON serializable, exclude it from results
@@ -453,3 +450,100 @@ class IsFDGQuantificationRunnable(ExperimentTest):
                 return Results(False, data=[msg])
 
         return Results(True, data=[])
+
+
+class IsInjectionTimeConsistent(ExperimentTest):
+    """PET technique requires injecting a positron-emitting radiopharmaceutical
+    (tracer) into the subject's bloodstream a certain amount of time before
+    imaging the subject. The timespan required between tracer injection and the
+    image acquisition event depends mostly on the compound used, body part
+    scanned and/or imaging protocol. PET modalities register both, the injection
+    time (ie. `Radiopharmaceutical Start Time`) and the image acquisition time
+    (ie. `AcquisitionTime`) as attributes in the DICOM header.
+    Test passes if the time elapsed between tracer injection and image
+    acquisition (as registered in the DICOM header attributes) is consistent
+    with the expected values for each type of PET session
+    (Flutemetamol PET: 90 min ± 20%; Fluorodeoxyglucose PET: 45 min ± 20%).
+    Fails otherwise."""
+
+    passing = 'BBRCDEV_E02124',
+    failing = 'BBRCDEV_E00278',
+
+    injection_times = {'flutemetamol': 90,
+                       'fluorodeoxyglucose': 45}
+
+    def pet_times(self, experiment_id, scan_id):
+        """Retrieve the radiopharmaceutical start datetime and acquisition
+        datetime from the DICOM header of a randomly selected file of the
+        given experiment and scan. """
+        import os
+        import tempfile
+        import pydicom
+
+        e = self.xnat_instance.select.experiment(experiment_id)
+        r = e.scan(scan_id).resource('DICOM')
+        f = r.files().first()
+
+        fh, fp = tempfile.mkstemp(suffix='.dcm')
+        os.close(fh)
+        f.get(fp)
+
+        d = pydicom.read_file(fp)
+        acq_date = d.AcquisitionDate
+        acq_time = d.AcquisitionTime
+        inj_time = d.RadiopharmaceuticalInformationSequence[0].RadiopharmaceuticalStartTime
+
+        os.remove(fp)
+
+        return acq_date+inj_time, acq_date+acq_time
+
+    def run(self, experiment_id):
+        passed = True
+        failed = {}
+
+        scan_data = self.xnat_instance.array.scans(experiment_id=experiment_id,
+                                                   scan_type='xnat:petScanData').data
+        scans = [item['xnat:petscandata/id'] for item in scan_data]
+
+        e = self.xnat_instance.select.experiment(experiment_id)
+        tracer = e.attrs.get('tracer_name').lower()
+        if tracer not in self.injection_times.keys():
+            return Results(False,
+                           data=['Unexpected/missing tracer ({})'.format(tracer)])
+
+        for s in scans:
+            s_type = e.scan(s).attrs.get('type')
+            inj, acq = self.pet_times(experiment_id, s)
+
+            # parse the date&time strings accordingly and substract injection to acquisition (secs)
+            from datetime import datetime
+            inj_dt = datetime.strptime(inj, '%Y%m%d%H%M%S.%f')
+            acq_dt = datetime.strptime(acq, '%Y%m%d%H%M%S.%f')
+            diff = (acq_dt-inj_dt).seconds
+
+            # set low and high timespan limits to threshold ± 20%
+            low_limit = self.injection_times[tracer] * 60 * (1 - 0.2)
+            high_limit = self.injection_times[tracer] * 60 * (1 + 0.2)
+            if not bool(low_limit < float(diff) < high_limit):
+                failed[s] = diff
+
+        if failed:
+            passed = False
+            failed['tracer'] = tracer
+
+        return Results(passed, data=failed)
+
+    def report(self):
+        report = []
+        if not self.results.has_passed:
+            if isinstance(self.results.data, list):
+                report = self.results.data
+            elif isinstance(self.results.data, dict):
+                tracer = self.results.data.pop('tracer')
+                report.append('Scans with abnormal injection-to-acquisition '
+                              'timespan ({} expected value: {} minutes):<br>'
+                              .format(tracer.capitalize(),
+                                      self.injection_times[tracer]))
+                report.append('<br>'.join(['{}: {:.2f} minutes'.format(k, v/60)
+                                           for k, v in self.results.data.items()]))
+        return report
