@@ -224,7 +224,8 @@ class PetSessionValidator(Validator):
                  pet.IsTracerDosageConsistent,
                  pet.HasUsableT1,
                  pet.IsCentiloidRunnable,
-                 pet.IsFDGQuantificationRunnable]
+                 pet.IsFDGQuantificationRunnable,
+                 pet.IsInjectionTimeConsistent]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -233,12 +234,15 @@ class DTIFITValidator(Validator):
         from bbrc.validation.processing import dtifit
         tests = [dtifit.HasCorrectNumberOfItems,
                  dtifit.HasCorrectItems,
-                 dtifit.HasCorrectANTsVersion,
+                 dtifit.HasCorrectMRtrix3Version,
                  dtifit.HasCorrectFSLVersion,
                  dtifit.DTIFITSnapshotFA,
                  dtifit.DTIFITSnapshotRGB,
                  dtifit.DTIFITSnapshotTOPUP,
-                 dtifit.HasFewNegativeVoxelsInMD]
+                 dtifit.HasFewNegativeVoxelsInMD,
+                 dtifit.HasAcceptableAverageSNR,
+                 dtifit.HasAcceptableAverageCNR,
+                 dtifit.HasAcceptableOutliersPercentage]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -344,3 +348,43 @@ class DONSURFValidator(Validator):
                  donsurf.HasCorrectFreeSurferVersion,
                  donsurf.DWIRegistrationSnapshot]
         super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class TauPetSessionValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.sanity import data, pet, tau_pet
+        tests = [data.IsAccessionNumberUnique,
+                 pet.IsSubjectIdCorrect,
+                 data.HasDuplicatedSequences,
+                 data.HasThumbnails,
+                 data.HasNifti,
+                 data.HasUncompressedPixelData,
+                 data.IsAcquisitionDateConsistent,
+                 data.IsInsertDateConsistent,
+                 data.HasValidDcm2niixVersion,
+                 data.HasCorrectSequences,
+                 tau_pet.IsScannerVersionCorrect,
+                 pet.IsSubjectWeightConsistent,
+                 # pet.IsTracerDosageConsistent,
+                 tau_pet.HasUsableT1,
+                 tau_pet.IsInjectionTimeConsistent]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class FreeSurfer7Validator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import freesurfer7
+        tests = [freesurfer7.HasCorrectItems,
+                 freesurfer7.HasCorrectFreeSurferVersion,
+                 freesurfer7.HasCorrectOSVersion,
+                 freesurfer7.IsT1OnlyHippocampalSegmentation,
+                 # freesurfer7.IsT1T2HippocampalSegmentation,
+                 # freesurfer7.IsT1IRHippocampalSegmentation,
+                 freesurfer7.IsT2MultispectralHippoSegRunnable,
+                 freesurfer7.IsIRMultispectralHippoSegRunnable,
+                 freesurfer7.IsFreeSurferTimewiseConsistent,
+                 freesurfer7.AreCAVolumesConsistent,
+                 freesurfer7.ReconAllAsegSnapshot,
+                 freesurfer7.ReconAllAparcSnapshot]
+                 # freesurfer7.HasAbnormalAsegFeatures]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
